/// <reference types="node" />
import { Queue } from "bullmq";
import { Logger } from "winston";
import { ClusterNode, ClusterOptions, RedisOptions } from "ioredis";
import { Registry } from "prom-client";
import { onJobHandler, RelayJob, Storage } from "./storage";
export interface RedisConnectionOpts {
    redisClusterEndpoints?: ClusterNode[];
    redisCluster?: ClusterOptions;
    redis?: RedisOptions;
    namespace?: string;
}
export interface ExponentialBackoffOpts {
    baseDelayMs: number;
    maxDelayMs: number;
    backOffFn?: (attemptsMade: number) => number;
}
export interface StorageOptions extends RedisConnectionOpts {
    queueName: string;
    attempts: number;
    concurrency?: number;
    exponentialBackoff?: ExponentialBackoffOpts;
    maxCompletedQueueSize?: number;
    maxFailedQueueSize?: number;
}
export type JobData = {
    parsedVaa: any;
    vaaBytes: string;
};
export declare class RedisStorage implements Storage {
    logger: Logger;
    vaaQueue: Queue<JobData, string[], string>;
    private worker;
    private readonly prefix;
    private readonly redis;
    registry: Registry;
    private metrics;
    private opts;
    workerId: string;
    constructor(opts: StorageOptions);
    getPrefix(): string;
    addVaaToQueue(vaaBytes: Buffer): Promise<RelayJob>;
    private vaaId;
    startWorker(handleJob: onJobHandler): void;
    stopWorker(): Promise<void>;
    spawnGaugeUpdateWorker(ms?: number): Promise<void>;
    private updateGauges;
    storageKoaUI(path: string): Koa.Middleware<Koa.DefaultState, Koa.DefaultContext, any>;
}
